import type { CcApiContextQuery } from '@aws-cdk/cloud-assembly-schema';
import { type SdkProvider } from '../api/aws-auth/sdk-provider';
import type { ContextProviderPlugin } from '../api/plugin';
export declare class CcApiContextProviderPlugin implements ContextProviderPlugin {
    private readonly aws;
    constructor(aws: SdkProvider);
    /**
     * This returns a data object with the value from CloudControl API result.
     * args.typeName - see https://docs.aws.amazon.com/cloudcontrolapi/latest/userguide/supported-resources.html
     * args.exactIdentifier -  use CC API getResource.
     * args.propertyMatch - use CCP API listResources to get resources and propertyMatch to search through the list.
     * args.propertiesToReturn - Properties from CC API to return.
     */
    getValue(args: CcApiContextQuery): Promise<{
        [key: string]: any;
    }[]>;
    private findResources;
    /**
     * Calls getResource from CC API to get the resource.
     * See https://docs.aws.amazon.com/cli/latest/reference/cloudcontrol/get-resource.html
     *
     * If the exactIdentifier is not found, then an empty map is returned.
     * If the resource is found, then a map of the identifier to a map of property values is returned.
     */
    private getResource;
    /**
     * Calls listResources from CC API to get the resources and apply args.propertyMatch to find the resources.
     * See https://docs.aws.amazon.com/cli/latest/reference/cloudcontrol/list-resources.html
     *
     * Since exactIdentifier is not specified, propertyMatch must be specified.
     * This returns an object where the ids are object keys and values are objects with keys of args.propertiesToReturn.
     */
    private listResources;
}
